@@ -2,13 +2,13 @@ from __future__ import annotations
 
 import asyncio
 import copy
-import json
 import logging
 import os
 import sys
 from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
+from xmlrpc.client import boolean
 
 import jsonschema
 from datayoga_core import blocks, utils
@@ -47,11 +47,12 @@ class Job():
         self.steps = steps
         self.error_handling = error_handling if error_handling else ErrorHandling.IGNORE
         self.initialized = False
+        self.root = None
 
     def init(self, context: Optional[Context] = None):
         # open any connections or setup needed
         self.context = context
-        self.root = None
+
         for step in self.steps:
             step.init(context)
 
@@ -68,12 +69,15 @@ class Job():
         self.root.add_done_callback(self.handle_results)
         self.initialized = True
 
-    def transform(self, data: List[Dict[str, Any]]) -> Tuple[List[Dict[str, Any]], List[Result]]:
+    def transform(self, data: List[Dict[str, Any]],
+                  deepcopy: boolean = True) -> Tuple[List[Dict[str, Any]],
+                                                     List[Result]]:
         """
         Transforms data
 
         Args:
             data (List[Dict[str, Any]]): Data
+            deepcopy: if True, performs a deepcopy before modifying records. otherwise, modifies in place. can affect performance.
 
         Returns:
             Tuple[List[Dict[str, Any]], List[Result]]: Transformed data and results
@@ -82,7 +86,8 @@ class Job():
             logger.debug("job has not been initialized yet, initializing...")
             self.init()
 
-        transformed_data = copy.deepcopy(data)
+        transformed_data = copy.deepcopy(data) if deepcopy else data
+
         results = []
         for step in self.steps:
             try:
